@@ -211,6 +211,12 @@ sw_autoip_network_interface_init(
 
 	sw_debug(SW_LOG_VERBOSE, "IDLE\n");
 
+	/*
+	 * initialize the MAC address
+	 */
+	err = sw_network_interface_mac_address(self->m_nif, &self->m_mac_addr);
+	sw_check_okay(err, exit);
+
 	/*
 	 * initialize the ip address
 	 */
