@@ -175,9 +175,12 @@ sw_mdns_stub_fina(
 							sw_mdns_stub	self)
 {
 	sw_corby_orb_unregister_servant(self->m_orb, SERVICE_OID);
+	sw_corby_object_fina(self->m_self);
 	sw_corby_object_fina(self->m_service);
 	sw_corby_orb_fina(self->m_orb);
 
+	sw_free( self );
+
 	return SW_OKAY;
 }
 
