@@ -65,6 +65,25 @@ static sw_result
 sw_posix_inet_socket(int * fd);
 
 
+#if defined(__CYGWIN__)
+
+static int
+if_nametoindex( const char * name )
+{
+	unsigned long index = 5381;
+	int c;
+
+	while ( c = *name++ )
+	{
+		index = ( ( index << 5 ) + index ) + c;
+	}
+
+	return index;
+}
+
+#endif
+
+	
 /*
 	sockaddr_dl is only referenced if we're using IP_RECVIF, 
    so only include the header in that case.
@@ -81,7 +100,7 @@ sw_posix_inet_socket(int * fd)
 {
 	sw_result err;
 
-	*fd = socket(AF_INET, SOCK_DGRAM, 0);
+	*fd = socket(AF_INET, SOCK_DGRAM, IPPROTO_IP);
 	err = sw_translate_error(*fd >= 0, SW_E_UNKNOWN);
 	sw_check_okay_log(err, exit);
 
@@ -186,6 +205,8 @@ sw_network_interface_up(
 	int				res;
 	sw_result		err = SW_OKAY;
 
+#if !defined(__CYGWIN__)
+
 	/* get a socket for ioctling */
 	err = sw_posix_inet_socket(&fd);
 	sw_check_okay(err, exit);
@@ -222,6 +243,8 @@ exit:
 
 	close(fd);
 
+#endif
+
 	return err;
 }
 
@@ -231,13 +254,14 @@ sw_network_interface_link_status(
 			sw_network_interface 	self, 
 			sw_bool					*	islinked)
 {
-#if defined(__linux__)
 	int 						fd;
-	struct ifreq			ifr;
 	int						r;
-	struct ethtool_value edata;
+	struct ifreq			ifr;
 	int						res;
 	sw_result 				err = SW_OKAY;
+#if defined(__linux__)
+	struct ethtool_value edata;
+#endif
 
 	sw_assert(self != NULL);		/* must be initialized */
 	sw_assert(islinked != NULL);	/* must be allocated */
@@ -251,6 +275,19 @@ sw_network_interface_link_status(
 	memset(&ifr, 0, sizeof(ifr));
 	strncpy(ifr.ifr_name, self->m_name, sizeof(ifr.ifr_name) - 1);
 
+	/* get the interface flags */
+	res = ioctl(fd, SIOCGIFFLAGS, &ifr);
+	err = sw_translate_error(res == 0, errno);
+	sw_check_okay_log(err, exit);
+
+	/* if it's down, we can't have a link */
+	if ((ifr.ifr_flags & IFF_UP) != IFF_UP)
+	{
+		*islinked = SW_FALSE;
+		goto exit;
+	}
+
+#if defined(__linux__)
 	edata.cmd = ETHTOOL_GLINK;
 	ifr.ifr_data = (caddr_t) &edata;
 
@@ -259,15 +296,13 @@ sw_network_interface_link_status(
 	sw_check_okay_log(err, exit);
 
 	*islinked = edata.data ? SW_TRUE : SW_FALSE;
+#endif
 
 exit:
 
 	close(fd);
 
 	return err;
-#else
-	return SW_OKAY;
-#endif
 }
 
 
@@ -363,11 +398,11 @@ sw_posix_network_interface_init_from_ifreq(
 	sw_posix_network_interface	nif,
 	struct ifreq				*	ifr)
 {
-	int 			sock = SW_INVALID_SOCKET;
-	char		*	cptr;
-	sw_bool		islinked;
-	int			res;
-	sw_result	err = SW_E_INIT;
+	int 				sock = SW_INVALID_SOCKET;
+	char			*	cptr;
+	sw_bool			islinked;
+	int				res;
+	sw_result		err = SW_E_INIT;
 
 	sw_assert(nif != NULL);		/* already allocated */
 	sw_assert(ifr != NULL);		/* already initialized */
@@ -385,12 +420,22 @@ sw_posix_network_interface_init_from_ifreq(
 	nif->m_super.m_index = if_nametoindex(ifr->ifr_name);
 
 	/* ip address */
+
 	sw_ipv4_address_init_from_saddr(&(nif->m_super.m_ipv4_address), ((struct sockaddr_in *) &ifr->ifr_addr)->sin_addr.s_addr);
 
 	/* get a socket for ioctling */
 	err = sw_posix_inet_socket(&sock);
 	sw_check_okay(err, exit);
 
+#if defined(SIOCGIFNETMASK)
+	// subnet mask
+
+	res = ioctl( sock, SIOCGIFNETMASK, ifr );
+	err = sw_translate_error( res != -1, errno );
+	sw_check_okay_log( err, exit );
+	sw_ipv4_address_init_from_saddr(&(nif->m_super.m_netmask), ((struct sockaddr_in*) &ifr->ifr_addr )->sin_addr.s_addr );
+#endif
+
 #if defined(SIOCGIFHWADDR)
 	/* mac address */
 	res = ioctl(sock, SIOCGIFHWADDR, ifr);
@@ -629,7 +674,7 @@ sw_network_interfaces(
 
 		ifr = (struct ifreq*) ptr;
 
-#if defined(__APPLE__) || defined(__FreeBSD__) || defined(__NetBSD__)
+#if defined(__APPLE__) || defined(__FreeBSD__) || defined(__NetBSD__) || defined(__OpenBSD__)
 
 		ptr += sizeof(ifr->ifr_name) + max(sizeof(struct sockaddr), ifr->ifr_addr.sa_len);
 
@@ -641,7 +686,7 @@ sw_network_interfaces(
 
 		ip_saddr = ((struct sockaddr_in *) &ifr->ifr_addr)->sin_addr.s_addr;
 
-		if ((ifr->ifr_addr.sa_family != AF_INET) || (ip_saddr == lb_saddr))
+		if ((ifr->ifr_addr.sa_family != AF_INET) || (ip_saddr == lb_saddr) || !ip_saddr)
 		{
 			continue;   /* ignore loopback+non-inet */
 		}
