@@ -261,7 +261,7 @@ sw_multicast_socket_super_init(
 	err = sw_translate_error(self->m_desc != SW_INVALID_SOCKET, sw_socket_errno());
 	sw_check_okay_log(err, exit);
 
-#if defined(__APPLE__) || defined(__VXWORKS__) || defined(__FreeBSD__)
+#if defined(__APPLE__) || defined(__VXWORKS__) || defined(__FreeBSD__) || defined(__NetBSD__)
    res = setsockopt(self->m_desc, SOL_SOCKET, SO_REUSEPORT, (char*) &opt, sizeof(opt));
 #else
 	res = setsockopt(self->m_desc, SOL_SOCKET, SO_REUSEADDR, (char*) &opt, sizeof(opt));
@@ -368,7 +368,7 @@ sw_socket_join_multicast_group(
 {
 	struct in_addr				addr;
    struct ip_mreq				mreq;	
-#if defined(__sun) || defined(__VXWORKS__)
+#if defined(__sun) || defined(__VXWORKS__) || defined(__NetBSD__) || defined(__OpenBSD__)
 	sw_uint8					real_ttl				= (sw_uint8) ttl;
 #else
 	sw_uint32					real_ttl				= ttl;
@@ -876,7 +876,7 @@ sw_socket_tcp_close(
 	 * ENOTCONN )
 	 */
 	err = sw_translate_error((res == 0) || (errno == ENOENT) || (errno == ENOTCONN), sw_socket_errno());
-   sw_check_okay_log(err, exit);
+   sw_check_okay(err, exit);
 #endif
 
 	res = sw_close_socket(self->m_desc);
