@@ -774,6 +774,7 @@ setup_interface(
 					sw_network_interface	netif)
 {
 	sw_ipv4_address									address;
+	sw_ipv4_address									netmask;
 	sw_int8												host[16];
 	struct PlatformNetworkInterface_struct	*	intf;
 	sw_uint32											index;
@@ -793,11 +794,15 @@ setup_interface(
 	 * initialize core data structure
 	 */
 	sw_network_interface_ipv4_address(netif, &address);
-	intf->m_super.ip.type					=	mDNSAddrType_IPv4;
-	intf->m_super.ip.ip.v4.NotAnInteger =	sw_ipv4_address_saddr(address);
-	intf->m_super.Advertise       		=	m->AdvertiseLocalAddresses;
+	sw_network_interface_netmask(netif, &netmask);
+
+	intf->m_super.ip.type						=	mDNSAddrType_IPv4;
+	intf->m_super.ip.ip.v4.NotAnInteger 	=	sw_ipv4_address_saddr(address);
+	intf->m_super.mask.type						=	mDNSAddrType_IPv4;
+	intf->m_super.mask.ip.v4.NotAnInteger	= sw_ipv4_address_saddr( netmask );
+	intf->m_super.Advertise       			=	m->AdvertiseLocalAddresses;
 	sw_network_interface_index(netif, &index);
-	intf->m_super.InterfaceID				=	(mDNSInterfaceID) index;
+	intf->m_super.InterfaceID					=	(mDNSInterfaceID) index;
 
 	/*
 	 * Set up multicast portion of interface.
