@@ -49,6 +49,7 @@
 #include "mDNSServant.h"
 #include <discovery/text_record.h>
 #include <salt/salt.h>
+#include <salt/debug.h>
 #include <corby/orb.h>
 #include <corby/channel.h>
 #include <corby/message.h>
@@ -279,7 +280,9 @@ sw_mdns_servant_parse_conf_line(
 				sw_string				type,
 				sw_string				domain,
 				sw_uint16			*	port,
-				sw_text_record		*	text_record);
+				sw_text_record		*	text_record,
+				sw_const_string		file,
+				int						lineno);
 
 
 /*
@@ -430,6 +433,7 @@ sw_mdns_servant_load_file(
 						sw_const_string	file)
 {
 	enum { LINE_LEN = 1024 };
+	int			lineno = 0;
 	sw_int8		line[LINE_LEN];
 	sw_size_t	len;
 	sw_result	err = SW_OKAY;
@@ -439,7 +443,9 @@ sw_mdns_servant_load_file(
 
 	while (len = LINE_LEN, sw_mdns_servant_getline(self, f, line, &len) == SW_OKAY)
 	{
-		if (line[0] != '#')
+		lineno++;
+
+		if ( len && ( line[0] != '#') )
 		{
 			sw_int8 			name[256];
 			sw_int8 			type[256];
@@ -447,11 +453,13 @@ sw_mdns_servant_load_file(
 			sw_uint16		port;
 			sw_text_record	text_record;
 	
-			if (sw_mdns_servant_parse_conf_line(self, line, len, name, type, domain, &port, &text_record) == SW_OKAY)
+			if (sw_mdns_servant_parse_conf_line(self, line, len, name, type, domain, &port, &text_record, file, lineno ) == SW_OKAY)
 			{
 				DNSStatus				status;
 				DNSRegistrationRef	ref;
 
+				sw_debug( SW_LOG_VERBOSE, "registering %s, %s, %s, %d, %s", name, type, domain, port, text_record );
+
 				status = DNSRegistrationCreate(
 									kDNSRegistrationFlagPreFormattedTextRecord|kDNSRegistrationFlagAutoRenameOnConflict,
 									name,
@@ -466,9 +474,23 @@ sw_mdns_servant_load_file(
 									NULL,
 									&ref);
 
+				if ( !status )
+				{
+					sw_debug( SW_LOG_NOTICE, "registered %s\n", name );
+				}
+				else
+				{
+					sw_debug( SW_LOG_ERROR, "error encountered while registering %s\n", name );
+				}
+
 				sw_text_record_fina(text_record);
 			}
 		}
+		else
+		{
+			sw_debug( SW_LOG_ERROR, "%s:%d: syntax error", file, lineno );
+			line[ len ] = '\0';
+		}
 	}
 
 exit:
@@ -899,7 +921,7 @@ sw_mdns_servant_query_record(
 	sw_result							err;
 
 	SW_UNUSED_PARAM(flags);
-	
+
 	/*
 	 * try to allocate space
 	 */
@@ -921,11 +943,13 @@ sw_mdns_servant_query_record(
 	node->m_cleanup				=	sw_mdns_servant_cleanup;
 	node->m_oid						=	oid;
 	
+printf("%s creating record \n");
 	err = DNSQueryRecordCreate(0, interface_index, fullname, rrtype, rrclass, (DNSQueryRecordCallBack) sw_mdns_servant_query_record_callback, node, &node->m_query_record_ref);
 	sw_check_okay(err, exit);
 
 exit:
 
+printf("%s done\n");
 	return err;
 }
 
@@ -1050,7 +1074,7 @@ sw_mdns_servant_dispatcher(
 
 		if (err)
 		{
-			err = sw_mdns_servant_publish_reply(NULL, SW_DISCOVERY_PUBLISH_INVALID, oid, client);
+			err = sw_mdns_servant_publish_reply(NULL, oid, SW_DISCOVERY_PUBLISH_INVALID, client);
 			sw_check_okay(err, exit);
 		}
 	}
@@ -1102,7 +1126,7 @@ sw_mdns_servant_dispatcher(
 
 		if (err)
 		{
-			sw_mdns_servant_publish_reply(NULL, SW_DISCOVERY_PUBLISH_INVALID, oid, client);
+			err = sw_mdns_servant_publish_reply(NULL, oid, SW_DISCOVERY_PUBLISH_INVALID, client);
 			sw_check_okay(err, exit);
 		}
 	}
@@ -1226,7 +1250,7 @@ sw_mdns_servant_dispatcher(
 		sw_corby_object	client;
 		sw_discovery_oid	oid;
 		sw_uint32			len;
-		
+
 		err = sw_corby_buffer_get_uint32(buffer, &interface_index, endian);
 		sw_check_okay(err, exit);
 
@@ -1237,10 +1261,10 @@ sw_mdns_servant_dispatcher(
 		sw_check_okay(err, exit);
 
 		err = sw_corby_buffer_get_uint16(buffer, &rrtype, endian);
-		sw_check_okay(err, exit);
+		sw_check_okay(err, exit);	
 
 		err = sw_corby_buffer_get_uint16(buffer, &rrclass, endian);
-		sw_check_okay(err, exit);
+		sw_check_okay(err, exit);	
 
 		err = sw_corby_buffer_get_object(buffer, &client, endian);
 		sw_check_okay(err, exit);
@@ -1594,7 +1618,7 @@ sw_mdns_servant_publish_host_callback(
 	
 	node = (sw_mdns_servant_client_node) inContext;
 	
-	(node->m_publish_reply)(NULL, (inStatusCode == kDNSNoErr) ? SW_DISCOVERY_PUBLISH_STARTED : SW_DISCOVERY_PUBLISH_INVALID, node->m_oid, node->m_extra);
+	(node->m_publish_reply)(NULL, node->m_oid, (inStatusCode == kDNSNoErr) ? SW_DISCOVERY_PUBLISH_STARTED : SW_DISCOVERY_PUBLISH_INVALID, node->m_extra);
 }
 
 
@@ -1933,6 +1957,8 @@ sw_mdns_servant_getline(
 			}
 		}
 	}
+
+	return SW_OKAY;
 }
 
 
@@ -1996,42 +2022,44 @@ sw_mdns_servant_parse_conf_line(
 					sw_string			type,
 					sw_string			domain,
 					sw_uint16		*	port,
-					sw_text_record	*	text_record)
+					sw_text_record	*	text_record,
+					sw_const_string	file,
+					int					lineno)
 {
-	sw_uint32 index = 0;
-	sw_int8	temp[256];
+	sw_uint32	index = 0;
+	sw_int8		temp[256];
+	sw_result	err;
 
-	if (sw_mdns_servant_next_token(self, line, &index, len, name) != SW_OKAY)
-	{
-		return SW_E_UNKNOWN;
-	}
+	err = sw_mdns_servant_next_token(self, line, &index, len, name);
+	sw_check_okay( err, exit );
 
-	if (sw_mdns_servant_next_token(self, line, &index, len, type) != SW_OKAY)
-	{
-		return SW_E_UNKNOWN;
-	}
+	err = sw_mdns_servant_next_token(self, line, &index, len, type);
+	sw_check_okay( err, exit );
 
-	if (sw_mdns_servant_next_token(self, line, &index, len, domain) != SW_OKAY)
-	{
-		return SW_E_UNKNOWN;
-	}
+	err = sw_mdns_servant_next_token(self, line, &index, len, domain);
+	sw_check_okay( err, exit );
 	
-	if (sw_mdns_servant_next_token(self, line, &index, len, temp) != SW_OKAY)
-	{
-		return SW_E_UNKNOWN;
-	}
+	err = sw_mdns_servant_next_token(self, line, &index, len, temp);
+	sw_check_okay( err, exit );
 
 	(*port) = (sw_uint16) atoi(temp);
 
-	if (sw_text_record_init(text_record) != SW_OKAY)
-	{
-		return SW_E_UNKNOWN;
-	}
+	err = sw_text_record_init(text_record);
+	sw_check_okay( err, exit );
 
 	while (sw_mdns_servant_next_token(self, line, &index, len, temp) == SW_OKAY)
 	{
 		sw_text_record_add_string(*text_record, temp);
 	}
 
-	return SW_OKAY;
+	err = SW_OKAY;
+
+exit:
+
+	if ( err )
+	{
+		sw_debug( SW_LOG_ERROR, "%s:%d: syntax error", file, lineno );
+	}
+
+	return err;
 }
