@@ -26,6 +26,7 @@
  *	either expressed or implied, of Porchdog Software.
  */
 
+#include "howl_config.h"
 #include "posix_main.h"
 #include <salt/debug.h>
 #include <mDNSServant.h>
@@ -37,8 +38,11 @@
 #include <fcntl.h>
 #include <errno.h>
 #include <stdio.h>
+#include <getopt.h>
 
 
+static int verbose_flag = 0;
+
 /*
  * Solaris defined SIOCGIFCONF etc in <sys/sockio.h> but 
  * other platforms don't even have that include file.  So, 
@@ -67,9 +71,11 @@ write_pidfile(char * dname, int * pidfd)
 	sw_check_okay_log(err, exit);
 	
    /* lock it */
+#if !defined(__CYGWIN__)
    res = lockf(*pidfd, F_TLOCK,0);
 	err = sw_translate_error(res == 0, errno);
 	sw_check_okay_log(err, exit);
+#endif
 
    /* write our pid */
    sprintf(str, "%d\n", getpid());
@@ -127,14 +133,15 @@ become_daemon(void)
 static void
 print_usage(const char * program)
 {
-	fprintf(stderr, "usage: %s [options]\n\n", program);
+	fprintf(stderr, "usage: %s [options]\n\n", "mDNSResponder" );
 	fprintf(stderr, "Options:\n\n");
 	fprintf(stderr, "-h              this help\n");
 	fprintf(stderr, "-v              display version\n");
 	fprintf(stderr, "-d              run in debug mode\n");
 	fprintf(stderr, "-i ifname       run only on interface ifname\n");
 	fprintf(stderr, "-a addr         run only on interface whose address is addr\n");
-	fprintf(stderr, "-f config_file  load config_file\n\n");
+	fprintf(stderr, "-f config_file  load config_file\n");
+	fprintf(stderr, "--verbose       verbose output\n\n");
 	exit(0);
 }
 
@@ -157,14 +164,19 @@ main(int argc, char ** argv)
 	sw_uint32			num_filters = 0;
 	sw_mdns_servant	servant;
 	sw_bool				done = SW_FALSE;
+	int					option_index;
 	int					pidfd;
 	int					opt;
 	sigset_t				signalSet;
 	int					sig;
 
-	/* sw_debug_enable(SW_TRUE); */
+	static struct option long_opts[] =
+	{
+		{ "verbose", no_argument, &verbose_flag, 1 },
+		{ 0, 0, 0, 0 }
+	};
 
-	while ((opt = getopt(argc, argv, "?hvdi:a:f:")) != EOF)
+	while ((opt = getopt_long(argc, argv, "?hvdi:a:f:", long_opts, &option_index ) ) != EOF)
 	{
 		switch (opt)
 		{
@@ -177,7 +189,7 @@ main(int argc, char ** argv)
 
 			case 'v':
 			{
-				fprintf(stderr, "mDNSResponder release " VERSION " Copyright(c) Porchdog Software 2004.\n");
+				fprintf(stderr, "mDNSResponder release " VERSION " Copyright(c) Porchdog Software 2003-2005.\n");
 				exit(0);
 			}
 			break;
@@ -205,15 +217,14 @@ main(int argc, char ** argv)
 				conf_file = sw_strdup(optarg);
 			}
 			break;
-
-			default:
-			{
-				print_usage(argv[0]);
-			}
-			break;
 		}
 	}
 
+	if ( verbose_flag )
+	{
+		sw_debug_set_level( SW_LOG_VERBOSE );
+	}
+
 	if (make_daemon)
 	{
 #if defined(__sun)
@@ -236,8 +247,6 @@ main(int argc, char ** argv)
 
 	sigfillset(&signalSet);
 
-	fprintf(stderr, "mDNSResponder starting up...\n");
-
 	if (sw_mdns_servant_new(&servant, 5335, filters, num_filters) != SW_OKAY)
 	{
 		sw_debug(SW_LOG_ERROR, "error initializing mdnsd\n");
@@ -288,8 +297,6 @@ main(int argc, char ** argv)
 		}
 	}
 
-	fprintf(stderr, "mDNSResponder shutting down...\n");
-
 	sw_mdns_servant_delete(servant);
 
 	close_pidfile(pidfd);
